(cli-import)=

# tmuxp import

(import-teamocil)=

## From teamocil

```{eval-rst}
.. click:: tmuxp.cli.import_config:command_import_teamocil
    :prog: tmuxp import teamocil
    :nested: full
```

````{tab} YAML

```console
$ tmuxp import teamocil /path/to/file.yaml
```

````

````{tab} JSON

```console
$ tmuxp import teamocil /path/to/file.json
```

````

(import-tmuxinator)=

## From tmuxinator

```{eval-rst}
.. click:: tmuxp.cli.import_config:command_import_tmuxinator
    :prog: tmuxp import tmuxinator
    :nested: short
```

````{tab} YAML

```console
$ tmuxp import tmuxinator /path/to/file.yaml
```

````

````{tab} JSON

```console
$ tmuxp import tmuxinator /path/to/file.json
```

````
